// Copyright (c) 2012-2014 Konstantin Isakov <ikm@zbackup.org> and ZBackup contributors, see CONTRIBUTORS
// Part of ZBackup. Licensed under GNU GPLv2 or later + OpenSSL, see LICENSE

bool verboseMode = true;

#ifndef NDEBUG
#ifdef HAVE_LIBUNWIND
#include "debug.hh"

#endif
#endif
